<?php
/*
Plugin Name: my-first-custom-post-type
Plugin URI: https://tobier.de/?p=265&preview=true
Description: Custom Post Type example from tobier.de/wordpress-custom-post-type
Version: 1.0
Author: Tobier / Tobias Keller
Author URI: https://tobier.de
*/

/* Exit if file access directly */
if ( ! defined( 'ABSPATH' ) ) exit;

// Call an instance from our class
$plugin_start = new my_first_post_type();

class my_first_post_type {

	/*
	 * Constructor - the brain of our class
	 * */
	public function __construct() {
		// registriert den neuen custom post type
		add_action( 'init', array( $this, 'register_custom_post_type' ) );
		// Shortcode für die Ausgabe aller Mitarbeiter
		add_shortcode('alle-mitarbeiter', array( $this, 'mitarbeiter_shortcode' ));
		// Post Template Mapping
		add_filter('single_template', array( $this, 'custom_post_type_single_mapping' ));
	}

	/*
	 * Register Custom Post Type
	 * Post Type Name = tobier_mitarbeiter
	 * */
	public function register_custom_post_type(){
		// Backend string values
		$labels = array(
			'name'               => _x( 'Mitarbeiter', 'post type general name' ),
			'singular_name'      => _x( 'Mitarbeiter', 'post type singular name' ),
			'add_new'            => __( 'Neuen Mitarbeiter anlegen'),
			'add_new_item'       => __( 'Neuen Mitarbeiter anlegen' ),
			'edit_item'          => __( 'Mitarbeiter Daten bearbeiten' ),
			'new_item'           => __( 'Neuer Mitarbeiter' ),
			'all_items'          => __( 'Alle Mitarbeiter' ),
			'view_item'          => __( 'Mitarbeiter ansehen' ),
			'search_items'       => __( 'Mitarbeiter durchsuchen' ),
			'not_found'          => __( 'Keine Mitarbeiter gefunden' ),
			'not_found_in_trash' => __( 'Keine Mitarbeiter im Papierkorb gefunden' ),
			'parent_item_colon'  => '',
			'menu_name'          => 'Mitarbeiter'
		);

		// args for the new post_type
		$args = array(
			'public'              => true,
			'show_ui'             => true,
			'show_in_menu'        => true,
			'menu_position'       => 5,
			'show_in_admin_bar'   => true,
			'show_in_nav_menus'   => true,
			'capability_type'     => 'post',
			'publicly_queryable'  => true,
			'exclude_from_search' => true,
			'supports'            => array( 'title', 'editor', 'thumbnail', 'custom-fields', 'revisions' ),
			'has_archive'         => false,
			'can_export'          => false,
			'rewrite'             => array('slug' => 'mitarbeiter' ),
			'labels'              => $labels,
		);

		// now register post_type with our args
		register_post_type( 'tobier_mitarbeiter', $args );
	}

	/*
	 * Checks if post is from our Post Type
	 * if so, we return our custom single template
	 * */
	public function custom_post_type_single_mapping($single) {

		global $post;

		if ( $post->post_type == 'tobier_mitarbeiter' ) {
		    if ( file_exists( plugin_dir_path( __FILE__ ) . '/mitarbeiter_single.php' ) ) {
			    return plugin_dir_path( __FILE__ ) . '/mitarbeiter_single.php';
		    }
		}

		return $single;
	}

	/*
	 * Creates the shortcode to display all employee
	 * */
	public function mitarbeiter_shortcode() {

		// Loop Arguments
		$args = array(
			'post_type'         => 'tobier_mitarbeiter',
			'post_status'       => array( 'publish' ),
			'posts_per_page'    => -1 // -1 = all posts
		);

		// Daten abgragen
		$loop = new WP_Query( $args );

		// Start output buffering
		ob_start();
		?>


		<div class="row">

		<?php
		// start des WordPress Loops für unseren post type
		while ( $loop->have_posts() ) : $loop->the_post();
			// post id abfragen
			$post_id = get_the_ID();
			// abfrage unseres custom fields "position"
			$position = get_post_meta( $post_id, 'position' );

			// Template Ausgabe
			?>
			<div class="col-md-4 text-center">
				<img style="max-height: 100px;" class="img-fluid mx-auto d-block rounded-circle" src="<?php echo get_the_post_thumbnail_url( $post_id, 'full' ) ?>">
			
				<span style="font-size: 1.5rem; font-weight: 700; color: #0e7c7b;" class="text-center"><?php echo get_the_title( $post_id ) ?></span>
				<p class="text-center">
					<b><?php echo $position[0] ?></b><br>
					<a href="<?php echo get_the_permalink( $post_id ) ?>" class="btn btn-tobi2" >Mehr erfahren</a>
				</p>
			</div>
		<?php
		// Ende unserer while-schleife
		endwhile;
		?>
		</div>

		<?php
		// stellt den ursprünglichen data Kontext wieder her
		wp_reset_postdata();

		// return buffer
		return ob_get_clean();
	}

}